# Generated by Django 4.2.6 on 2023-10-09 14:12

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        ("evalu", "0012_deletion"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="evaluationphase",
            name="results_date_start",
        ),
        migrations.AlterField(
            model_name="comparisongroup",
            name="site",
            field=models.ForeignKey(
                default=1,
                editable=False,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="comparisonresult",
            name="site",
            field=models.ForeignKey(
                default=1,
                editable=False,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="doneevaluation",
            name="site",
            field=models.ForeignKey(
                default=1,
                editable=False,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="doneevaluationcomparison",
            name="site",
            field=models.ForeignKey(
                default=1,
                editable=False,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="evaluationgroup",
            name="site",
            field=models.ForeignKey(
                default=1,
                editable=False,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="evaluationitem",
            name="site",
            field=models.ForeignKey(
                default=1,
                editable=False,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="evaluationpart",
            name="site",
            field=models.ForeignKey(
                default=1,
                editable=False,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="evaluationphase",
            name="site",
            field=models.ForeignKey(
                default=1,
                editable=False,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="evaluationregistration",
            name="site",
            field=models.ForeignKey(
                default=1,
                editable=False,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="evaluationresult",
            name="site",
            field=models.ForeignKey(
                default=1,
                editable=False,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="sites.site",
            ),
        ),
    ]
